@@ -6,7 +6,7 @@
 
 # Environment
 
-from .environment.emerging_perfluoroalkyls import EmergingPerFluoroAlkyls
+from global_chem.environment.emerging_perfluoroalkyls import EmergingPerFluoroAlkyls
 
 # Medicinal Chemistry
 
